@@ -5,8 +5,10 @@ import argparse
 import sys
 from subprocess import check_call
 
-from colorama import init, Fore
-from git import Repo, Remote
+from colorama import Fore
+from colorama import init
+from git import Remote
+from git import Repo
 
 
 def create_branch(version):
@@ -50,7 +52,7 @@ def changelog(version, write_out=False):
     else:
         addopts = ["--draft"]
     print(f"{Fore.CYAN}Generating CHANGELOG")
-    check_call(["towncrier", "--yes", "--version", version] + addopts)
+    check_call(["towncrier", "build", "--yes", "--version", version] + addopts)
 
 
 def main():
